.. _spkg_zipp:

zipp: A pathlib-compatible zipfile object wrapper
===========================================================

Description
-----------

A pathlib-compatible Zipfile object wrapper. A backport of the Path object.

License
-------

MIT License


Upstream Contact
----------------

Home page: https://github.com/jaraco/zipp

Dependencies
------------

Python, Setuptools

Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    3.21.0

version_requirements.txt::

    zipp >=0.5.2


Equivalent System Packages
--------------------------

.. tab:: conda-forge

   .. CODE-BLOCK:: bash

       $ conda install zipp 


.. tab:: Fedora/Redhat/CentOS

   .. CODE-BLOCK:: bash

       $ sudo dnf install python3-zipp 


.. tab:: Gentoo Linux

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-python/zipp 


.. tab:: MacPorts

   .. CODE-BLOCK:: bash

       $ sudo port install py-zipp 


.. tab:: Void Linux

   .. CODE-BLOCK:: bash

       $ sudo xbps-install python3-zipp 



See https://repology.org/project/python:zipp/versions

If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then ``./configure``
will check if the system package can be used.

